@@ -108,6 +108,15 @@ export const registerBbyButtons = () => {
       'add-image-player-step',
       'ipybbycell'
     ),
+    Jupyter.keyboard_manager.actions.register(
+      {
+        help: '添加「视频」',
+        icon: 'fa-file-video-o',
+        handler: addVideoPlayerStep,
+      },
+      'add-video-player-step',
+      'ipybbycell'
+    ),
   ]);
 
   Jupyter.toolbar.add_buttons_group([
@@ -431,6 +440,19 @@ const addImagePlayerStep = function () {
 `);
 };
 
+const addVideoPlayerStep = function () {
+  insertCodeInCurrentMarkdownCell(`
+<!-- ---------------------------------------- -->
+<!-- /////////// 视频播放器 Begin /////////// -->
+<!-- ---------------------------------------- -->
+<div class="ipy-ali-player" data-vid="【此处填入视频vid】" data-aspect-ratio="4/3"></div>
+<!-- ---------------------------------------- -->
+<!-- /////////// 视频播放器 End //////////// -->
+<!-- ---------------------------------------- -->
+`);
+};
+
+
 const addFileCell = function () {
   insertCodeCellBelow(`#platform-lock-hidden
 
