@@ -9,6 +9,8 @@ export interface ICell
   metadata: IJupyterCellMetadata;
   execution_count: number | null;
   element: HTMLElement[];
+  get_text: () => string;
+  set_text: any;
 }
 
 export interface IJupyterNotebook {
@@ -21,7 +23,7 @@ export interface IJupyterNotebook {
   get_selected_cell: () => ICell;
   get_selected_index: () => number | null;
   focus_cell: () => void;
-  select: (index: number) => void;
+  select: (index: number) => any;
   insert_cell_below: (type: 'code' | 'markdown') => any;
   delete_cells: () => void;
   toJSON: () => Record<string, any>;
